@@ -414,9 +414,11 @@ const augmentNodesWithMetadata = ({
       path: node.path,
       isLink: node.isLink,
       realpath: node.realpath,
+      [_type]: node[_type],
       [_invalid]: node[_invalid],
       [_missing]: node[_missing],
-      [_dedupe]: true,
+      // if it's missing, it's not deduped, it's just missing
+      [_dedupe]: !node[_missing],
     }
   } else {
     // keeps track of already seen nodes in order to check for dedupes
@@ -441,7 +443,7 @@ const augmentNodesWithMetadata = ({
 }
 
 const sortAlphabetically = (a, b) =>
-  a.pkgid.localeCompare(b.pkgid)
+  a.pkgid.localeCompare(b.pkgid, 'en')
 
 const humanOutput = ({ color, result, seenItems, unicode }) => {
   // we need to traverse the entire tree in order to determine which items
